@@ -86,7 +86,7 @@
 #define KI18N_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KI18N_NO_DEPRECATED
-#  define KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KI18N_NO_DEPRECATED_WARNINGS
 #  define KI18N_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KI18N_DEPRECATED_WARNINGS_SINCE KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KI18N_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KI18N_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
@@ -180,7 +180,7 @@
 #define KI18N_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KI18N_NO_DEPRECATED
-#  define KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KI18N_NO_DEPRECATED_WARNINGS
 #  define KI18N_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +190,7 @@
 #  ifdef KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KI18N_DEPRECATED_WARNINGS_SINCE KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KI18N_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KI18N_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
